@@ -17,7 +17,7 @@
 
 package Git::Hooks::CheckJira;
 {
-  $Git::Hooks::CheckJira::VERSION = '0.041';
+  $Git::Hooks::CheckJira::VERSION = '0.042';
 }
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
 
@@ -61,15 +61,17 @@ sub grok_msg_jiras {
     my ($git, $msg) = @_;
 
     my $matchkey = $git->get_config($CFG => 'matchkey');
-    my $matchlog = $git->get_config($CFG => 'matchlog');
+    my @matchlog = $git->get_config($CFG => 'matchlog');
 
     # Grok the JIRA issue keys from the commit log
-    if ($matchlog) {
-        if (my ($match) = ($msg =~ /$matchlog/o)) {
-            return $match =~ /$matchkey/go;
-        } else {
-            return ();
+    if (@matchlog) {
+        my @keys;
+        foreach my $matchlog (@matchlog) {
+            if (my ($match) = ($msg =~ /$matchlog/)) {
+                push @keys, ($match =~ /$matchkey/go);
+            }
         }
+        return @keys;
     } else {
         return $msg =~ /$matchkey/go;
     }
@@ -340,7 +342,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -482,6 +484,11 @@ Wikimedia.
 
 =back
 
+This is a multi-valued option. You may specify it more than once. All
+regexes are tried and JIRA keys are looked for in all of them. This
+allows you to more easily accomodate more than one way of specifying
+JIRA keys if you wish.
+
 =head2 githooks.checkjira.project STRING
 
 By default, the committer can reference any JIRA issue in the commit
